@@ -8,6 +8,7 @@ from sportrefpy.mlb.team import MLBFranchise
 from sportrefpy.cbb.cbb import CBBSchool
 from sportrefpy.cfb.cfb import CFBSchool
 from sportrefpy.nhl.analysis import compare_franchises as nhl_compare_franchises
+from sportrefpy.mlb.analysis import compare_franchises as mlb_compare_franchises
 
 
 def test_NBA_franchise():
@@ -61,16 +62,41 @@ def test_NFL_seasons():
     seasons = eagles.season_history()
     assert seasons.loc[2017, 'Playoffs'] == 'Won SB'
 
+def test_NFL_coaching():
+    jets = NFLFranchise('nyj')
+    coaches = jets.coaches_all_time_data()
+    assert 'Rex Ryan' in coaches.index
+
 
 def test_MLB_franchise():
     dodgers = MLBFranchise('LAD')
-    assert dodgers.franchise == "Los Angeles Dodgers"
+    assert dodgers.franchise_name == "Los Angeles Dodgers"
 
 def test_MLB_seasons():
     nyy = MLBFranchise('NYY')
     seasons = nyy.season_history()
     assert seasons.loc[1921, 'Playoffs'] == 'Lost WS (5-3)'
 
+def test_MLB_roster():
+    braves = MLBFranchise('ATL')
+    roster = braves.roster(1995)
+    assert 'Chipper Jones' in roster.index
+
+def test_MLB_batters():
+    dodgers = MLBFranchise('LAD')
+    batters = dodgers.batters_all_time_stats()
+    assert batters.loc['Jackie Robinson', 'G'] == 1382
+
+def test_MLB_pitchers():
+    pirates = MLBFranchise('PIT')
+    pitchers = pirates.pitchers_all_time_stats()
+    assert pitchers.loc['Jim Bunning', 'L'] == 23
+
+def compare_MLB_franchise():
+    comparison = mlb_compare_franchises(['PHI', 'DET'])
+    assert comparison.loc['Philadelphia Phillies', 'L'] > \
+        comparison.loc['Detroit Tigers', 'L']
+
 
 def test_CBB_school():
     af = CBBSchool('air-force')
